#!/bin/sh
#################################################################
# A transfer engine to use in a file transfer provider.
# -- Copy files between ESXi-vMA by scp command.
#
# yParametersz
#  $1 : HOSTNAME  Connection host name or IP address.
#  $2 : USERNAME  User name.
#  $3 : PASSWORD  Password.
#  $4 : DIRECTION Copy direction (0: ESXi to vMA, 1: vMA to ESXi).
#  $5 : SRCPATH   Directory of Copy from (ex. /tmp, /tmp/*.log)
#  $6 : DSTPATH   Directory of Copy to
#  $7 : (option)  -d to debug-mode
#
#################################################################
if [ $# -lt 6 ] ; then
	exit 1
fi
HOSTNAME=$1
USERNAME=$2
PASSWORD=$3
DIRECTION=$4
SRCPATH=$5
DSTPATH=$6
DEBUGOPT=
if [ $# -eq 7 ]; then
	DEBUGOPT=$7
fi

PVD_CACHE_DIR=/opt/hitachi/snv/provider/tmp/cache
SNV_LOGFILE=${PVD_CACHE_DIR}/snvesxscp.log

if [ ! -d ${PVD_CACHE_DIR} ] ; then
	mkdir -p ${PVD_CACHE_DIR}
else
	rm -f ${SNV_LOGFILE}
fi
if [ $DIRECTION = "0" ] ; then
	PARAMS="${USERNAME}@${HOSTNAME}:${SRCPATH} ${DSTPATH}"
else
	PARAMS="${SRCPATH} ${USERNAME}@${HOSTNAME}:${DSTPATH}"
fi

EXEC="sh -c \"scp -Cpqr -o StrictHostKeyChecking=no -o ConnectTimeout=5 ${PARAMS}\""


expect ${DEBUGOPT} -c "
log_file ${SNV_LOGFILE}
set timeout 30
set ConEsxi 0
set pwcount 2

log_user 0
spawn ${EXEC}
expect_after eof {
	if {\$ConEsxi == 0} {
		send_user \"connection to ${HOSTNAME} failed\n\"
		exit 5
	}
}

expect {
	\"\[Pp]assword:\" {
		send \"${PASSWORD}\n\"
		set pwcount [expr \$pwcount-1]
		if {\$pwcount == 0} {
			send_user \"invalid password or account\n\"
			set ConEsxi 0
			exit 6
		}
		set ConEsxi 1
		exp_continue
	} \"${USERNAME}@${HOSTNAME}'s \[Pp]assword:\" {
		send \"${PASSWORD}\n\"
		set pwcount [expr \$pwcount-1]
		if {\$pwcount == 0} {
			send_user \"invalid password or account\n\"
			set ConEsxi 0
			exit 6
		}
		set ConEsxi 1
		exp_continue
	} incorrect {
		send_user \"invalid password or account\n\"
		set ConEsxi 0
		exit 3
	} \"scp: ${SRCPATH}: No such file or directory\" {
		send_user \"file or directory not found\n\"
		exit 2
	} \"${DSTPATH}: No such file or directory\" {
		send_user \"file or directory not found\n\"
		exit 2
	} timeout {
		send_user \"connection to ${HOSTNAME} timed out\n\"
		exit 4
	}
}
"
RESULT=$?

if [ ! -z ${DEBUGOPT} ]; then
	echo "RESULT=${RESULT}"
fi
exit ${RESULT}

